@@ -28,86 +28,39 @@
 
 This AWS Solutions Construct implements an AWS WAF web ACL connected to Amazon API Gateway REST API.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import * as lambda from "aws-cdk-lib/aws-lambda";
+import * as api from '@aws-cdk/aws-apigateway';
+import * as lambda from "@aws-cdk/aws-lambda";
 import { ApiGatewayToLambda } from '@aws-solutions-constructs/aws-apigateway-lambda';
 import { WafwebaclToApiGatewayProps, WafwebaclToApiGateway } from "@aws-solutions-constructs/aws-wafwebacl-apigateway";
 
 const apiGatewayToLambda = new ApiGatewayToLambda(this, 'ApiGatewayToLambdaPattern', {
-  lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler',
-    code: lambda.Code.fromAsset(`lambda`)
-  }
+    lambdaFunctionProps: {
+        runtime: lambda.Runtime.NODEJS_14_X,
+        handler: 'index.handler',
+        code: lambda.Code.fromAsset(`lambda`)
+    }
 });
 
 // This construct can only be attached to a configured API Gateway.
 new WafwebaclToApiGateway(this, 'test-wafwebacl-apigateway', {
-  existingApiGatewayInterface: apiGatewayToLambda.apiGateway
+    existingApiGatewayInterface: apiGatewayToLambda.apiGateway
 });
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_apigateway_lambda import ApiGatewayToLambda
-from aws_solutions_constructs.aws_wafwebacl_apigateway import WafwebaclToApiGatewayProps, WafwebaclToApiGateway
-from aws_cdk import (
-    aws_apigateway as api,
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-api_gateway_to_lambda = ApiGatewayToLambda(self, 'ApiGatewayToLambdaPattern',
-                                    lambda_function_props=_lambda.FunctionProps(
-                                        code=_lambda.Code.from_asset(
-                                            'lambda'),
-                                        runtime=_lambda.Runtime.PYTHON_3_9,
-                                        handler='index.handler'
-                                    )
-                                    )
-
-# This construct can only be attached to a configured API Gateway.
-WafwebaclToApiGateway(self, 'test_wafwebacl_apigateway',
-                    existing_api_gateway_interface=api_gateway_to_lambda.api_gateway
-                    )
+```text
+new WafwebaclToApiGateway(scope: Construct, id: string, props: WafwebaclToApiGatewayProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.apigateway.*;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.apigatewaylambda.*;
-import software.amazon.awsconstructs.services.wafwebaclapigateway.*;
-
-final ApiGatewayToLambda apiGatewayToLambda = new ApiGatewayToLambda(this, "ApiGatewayToLambdaPattern",
-        new ApiGatewayToLambdaProps.Builder()
-                .lambdaFunctionProps(new FunctionProps.Builder()
-                        .runtime(Runtime.NODEJS_14_X)
-                        .code(Code.fromAsset("lambda"))
-                        .handler("index.handler")
-                        .build())
-                .build());
-
-// This construct can only be attached to a configured Application Load
-// Balancer.
-new WafwebaclToApiGateway(this, "test-wafwebacl-apigateway", new WafwebaclToApiGatewayProps.Builder()
-        .existingApiGatewayInterface(apiGatewayToLambda.getApiGateway())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`WafwebaclToApiGatewayProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -154,7 +107,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -166,17 +119,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_wafv2
-import aws_cdk.core
+import constructs
 
 
 class WafwebaclToApiGateway(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-wafwebacl-apigateway.WafwebaclToApiGateway",
 ):
@@ -186,12 +137,12 @@ class WafwebaclToApiGateway(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -203,19 +154,6 @@ class WafwebaclToApiGateway(
         :access: public
         :summary: Constructs a new instance of the WafwebaclToApiGateway class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToApiGatewayProps(
             existing_api_gateway_interface=existing_api_gateway_interface,
             existing_webacl_obj=existing_webacl_obj,
@@ -224,12 +162,12 @@ class WafwebaclToApiGateway(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.IRestApi:
         return typing.cast(aws_cdk.aws_apigateway.IRestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="webacl")
     def webacl(self) -> aws_cdk.aws_wafv2.CfnWebACL:
         return typing.cast(aws_cdk.aws_wafv2.CfnWebACL, jsii.get(self, "webacl"))
@@ -250,7 +188,7 @@ class WafwebaclToApiGatewayProps:
         *,
         existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
+        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
     ) -> None:
         '''
         :param existing_api_gateway_interface: The existing API Gateway instance that will be protected with the WAF web ACL.
@@ -261,18 +199,6 @@ class WafwebaclToApiGatewayProps:
         '''
         if isinstance(webacl_props, dict):
             webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
-        if __debug__:
-            def stub(
-                *,
-                existing_api_gateway_interface: aws_cdk.aws_apigateway.IRestApi,
-                existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-                webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument existing_api_gateway_interface", value=existing_api_gateway_interface, expected_type=type_hints["existing_api_gateway_interface"])
-            check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
-            check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_interface": existing_api_gateway_interface,
         }
